@@ -1,9 +1,10 @@
 package HTML::FormFu::Filter::Split;
 
-use strict;
-use base 'HTML::FormFu::Filter';
+use Moose;
+extends 'HTML::FormFu::Filter';
 
-__PACKAGE__->mk_accessors(qw/ regex limit /);
+has regex => ( is => 'rw', traits => ['Chained'] );
+has limit => ( is => 'rw', traits => ['Chained'] );
 
 sub filter {
     my ( $self, $value ) = @_;
@@ -17,16 +18,20 @@ sub filter {
 
     my @values = split /$regex/, $value, $limit;
 
+    return if !@values;
+
     return \@values;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
 
 =head1 NAME
 
-HTML::FormFu::Filter::Split
+HTML::FormFu::Filter::Split - filter splitting a singe value into an arrayref
 
 =head1 SYNOPSIS
 
